@@ -45,6 +45,7 @@ pub struct Entry {
     pub identity: Vec<u8>,
     pub entity: Vec<u8>,
     pub attribute: String,
-    pub value: String,
+    pub value_str: Option<String>,
+    pub value_num: Option<f64>,
     pub immutable: bool,
 }
