@@ -10,7 +10,7 @@ pub mod inner;
 pub mod lang;
 
 use crate::addressing::{Address, Addressable};
-use crate::database::constants::{IS_OF_TYPE_ATTR, TYPE_ADDR, TYPE_HAS_ATTR, TYPE_INVARIANT};
+use crate::database::constants::{IS_OF_TYPE_ATTR, TYPE_ADDR, TYPE_HAS_ATTR, TYPE_INVARIANT, LABEL_ATTR};
 use crate::database::entry::{Entry, EntryValue, ImmutableEntry};
 use crate::database::inner::models;
 use crate::database::inner::schema::data;
@@ -142,6 +142,7 @@ impl UpEndDatabase {
         connection.insert_entry(Entry::try_from(&*TYPE_INVARIANT)?)?;
         upend_insert_addr!(connection, TYPE_ADDR, IS_OF_TYPE_ATTR, TYPE_ADDR)?;
         upend_insert_val!(connection, TYPE_ADDR, TYPE_HAS_ATTR, TYPE_HAS_ATTR)?;
+        upend_insert_val!(connection, TYPE_ADDR, LABEL_ATTR, "UpEnd Type")?;
 
         initialize_hier(&connection)?;
 
@@ -276,7 +277,7 @@ impl UpEndConnection {
 
         let primary = data
             .filter(entity.eq(object_address.encode()?))
-            .or_filter(value.eq(EntryValue::Address(object_address).to_string()?))
+            .or_filter(value_str.eq(EntryValue::Address(object_address).to_string()?))
             .load::<models::Entry>(&self.conn)?;
 
         let entries = primary
@@ -313,7 +314,7 @@ impl UpEndConnection {
         let matches = data
             .filter(identity.eq(object_address.encode()?))
             .or_filter(entity.eq(object_address.encode()?))
-            .or_filter(value.eq(EntryValue::Address(object_address).to_string()?));
+            .or_filter(value_str.eq(EntryValue::Address(object_address).to_string()?));
 
         Ok(diesel::delete(matches).execute(&self.conn)?)
     }
