@@ -7,7 +7,7 @@ use std::{fs, iter};
 
 use crate::addressing::Address;
 use crate::database::constants::{
-    HIER_HAS_ATTR, IS_OF_TYPE_ATTR, TYPE_ADDR, TYPE_BASE_ATTR, TYPE_HAS_ATTR,
+    HIER_HAS_ATTR, IS_OF_TYPE_ATTR, TYPE_ADDR, TYPE_BASE_ATTR, TYPE_HAS_ATTR, LABEL_ATTR,
 };
 use crate::database::entry::{Entry, EntryValue, InvariantEntry};
 use crate::database::hierarchies::{
@@ -22,7 +22,6 @@ use chrono::prelude::*;
 use log::{debug, error, info, warn};
 use lru::LruCache;
 use rayon::prelude::*;
-use serde_json::Value;
 use walkdir::WalkDir;
 
 const BLOB_TYPE: &str = "BLOB";
@@ -34,7 +33,7 @@ const FILE_SIZE_KEY: &str = "FILE_SIZE";
 lazy_static! {
     static ref BLOB_TYPE_INVARIANT: InvariantEntry = InvariantEntry {
         attribute: String::from(TYPE_BASE_ATTR),
-        value: EntryValue::Value(Value::from(BLOB_TYPE)),
+        value: EntryValue::String(String::from(BLOB_TYPE)),
     };
     static ref BLOB_TYPE_ADDR: Address = BLOB_TYPE_INVARIANT.entity().unwrap();
 }
@@ -46,6 +45,7 @@ fn initialize_types(connection: &UpEndConnection) -> Result<()> {
     upend_insert_val!(connection, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MTIME_KEY)?;
     upend_insert_val!(connection, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_SIZE_KEY)?;
     upend_insert_val!(connection, BLOB_TYPE_ADDR, TYPE_HAS_ATTR, FILE_MIME_KEY)?;
+    upend_insert_val!(connection, BLOB_TYPE_ADDR, LABEL_ATTR, "Data Blob")?;
 
     Ok(())
 }
@@ -390,13 +390,13 @@ fn insert_file_with_metadata(
     let size_entry = Entry {
         entity: Address::Hash(hash.clone()),
         attribute: FILE_SIZE_KEY.to_string(),
-        value: EntryValue::Value(Value::from(size)),
+        value: EntryValue::Number(size as f64),
     };
 
     let mime_entry = mime_type.map(|mime_type| Entry {
         entity: Address::Hash(hash.clone()),
         attribute: FILE_MIME_KEY.to_string(),
-        value: EntryValue::Value(Value::String(mime_type)),
+        value: EntryValue::String(mime_type),
     });
 
     // Add the appropriate entries w/r/t virtual filesystem location
@@ -436,9 +436,9 @@ fn insert_file_with_metadata(
         let name_entry = Entry {
             entity: dir_has_entry_addr,
             attribute: ALIAS_KEY.to_string(),
-            value: EntryValue::Value(Value::String(
+            value: EntryValue::String(
                 filename.as_os_str().to_string_lossy().to_string(),
-            )),
+            ),
         };
         connection.insert_entry(name_entry)?;
 
