@@ -5,12 +5,13 @@ use crate::database::lang::Query;
 use crate::database::UpEndDatabase;
 use crate::filesystem::add_file;
 use crate::previews::PreviewStore;
-use crate::util::hash::{decode, encode, Hashable};
+use crate::util::hash::{b58_decode, b58_encode, Hashable};
 use crate::util::jobs::JobContainer;
 use actix_files::NamedFile;
 use actix_multipart::Multipart;
 use actix_web::error::{ErrorBadRequest, ErrorInternalServerError, ErrorNotFound};
 use actix_web::http;
+use actix_web::http::header::{ContentDisposition, DispositionType};
 use actix_web::{delete, error, get, post, put, web, Either, Error, HttpResponse};
 use anyhow::{anyhow, Result};
 use futures_util::TryStreamExt;
@@ -42,6 +43,7 @@ pub struct State {
 #[derive(Deserialize)]
 pub struct RawRequest {
     native: Option<String>,
+    inline: Option<String>,
 }
 
 #[get("/api/raw/{hash}")]
@@ -50,8 +52,9 @@ pub async fn get_raw(
     web::Query(query): web::Query<RawRequest>,
     hash: web::Path<String>,
 ) -> Result<Either<NamedFile, HttpResponse>, Error> {
-    let address = Address::decode(&decode(hash.into_inner()).map_err(ErrorInternalServerError)?)
-        .map_err(ErrorInternalServerError)?;
+    let address =
+        Address::decode(&b58_decode(hash.into_inner()).map_err(ErrorInternalServerError)?)
+            .map_err(ErrorInternalServerError)?;
     if let Address::Hash(hash) = address {
         let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
 
@@ -71,7 +74,14 @@ pub async fn get_raw(
             let file_path = state.upend.vault_path.join(&file.path);
 
             if query.native.is_none() {
-                Ok(Either::A(NamedFile::open(file_path)?))
+                Ok(Either::A(if query.inline.is_some() {
+                    NamedFile::open(file_path)?.set_content_disposition(ContentDisposition {
+                        disposition: DispositionType::Inline,
+                        parameters: vec![],
+                    })
+                } else {
+                    NamedFile::open(file_path)?
+                }))
             } else if state.desktop_enabled {
                 #[cfg(feature = "desktop")]
                 {
@@ -135,7 +145,7 @@ pub async fn get_query(
     let mut result: HashMap<String, Entry> = HashMap::new();
     for entry in entries {
         result.insert(
-            encode(
+            b58_encode(
                 entry
                     .address()
                     .map_err(ErrorInternalServerError)?
@@ -157,7 +167,7 @@ impl EntriesAsHash for Vec<Entry> {
     fn as_hash(&self) -> Result<HashMap<String, &Entry>> {
         let mut result: HashMap<String, &Entry> = HashMap::new();
         for entry in self {
-            result.insert(encode(entry.address()?.encode()?), entry);
+            result.insert(b58_encode(entry.address()?.encode()?), entry);
         }
 
         Ok(result)
@@ -172,7 +182,7 @@ pub async fn get_object(
     let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
     let result: Vec<Entry> = connection
         .retrieve_object(
-            Address::decode(&decode(address_str.into_inner()).map_err(ErrorBadRequest)?)
+            Address::decode(&b58_decode(address_str.into_inner()).map_err(ErrorBadRequest)?)
                 .map_err(ErrorBadRequest)?,
         )
         .map_err(ErrorInternalServerError)?;
@@ -223,7 +233,7 @@ pub async fn put_object(
                     .map_err(ErrorInternalServerError)?;
 
                 if existing_files.is_empty() {
-                    let addr_str = encode(address.encode().map_err(ErrorInternalServerError)?);
+                    let addr_str = b58_encode(address.encode().map_err(ErrorInternalServerError)?);
                     let final_name = if let Some(filename) = filename {
                         format!("{addr_str}_{filename}")
                     } else {
@@ -256,7 +266,7 @@ pub async fn put_object(
 
     Ok(HttpResponse::Ok().json(
         [(
-            encode(result_address.encode().map_err(ErrorInternalServerError)?),
+            b58_encode(result_address.encode().map_err(ErrorInternalServerError)?),
             entry,
         )]
         .iter()
@@ -273,7 +283,7 @@ pub async fn delete_object(
     let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
     let _ = connection
         .remove_object(
-            Address::decode(&decode(address_str.into_inner()).map_err(ErrorBadRequest)?)
+            Address::decode(&b58_decode(address_str.into_inner()).map_err(ErrorBadRequest)?)
                 .map_err(ErrorInternalServerError)?,
         )
         .map_err(ErrorInternalServerError)?;
@@ -370,8 +380,9 @@ pub async fn get_file(
     state: web::Data<State>,
     hash: web::Path<String>,
 ) -> Result<HttpResponse, Error> {
-    let address = Address::decode(&decode(hash.into_inner()).map_err(ErrorInternalServerError)?)
-        .map_err(ErrorInternalServerError)?;
+    let address =
+        Address::decode(&b58_decode(hash.into_inner()).map_err(ErrorInternalServerError)?)
+            .map_err(ErrorInternalServerError)?;
 
     if let Address::Hash(hash) = address {
         let connection = state.upend.connection().map_err(ErrorInternalServerError)?;
@@ -417,7 +428,7 @@ pub async fn get_thumbnail(
     #[cfg(feature = "previews")]
     if let Some(preview_store) = &state.preview_store {
         let hash = hash.into_inner();
-        let address = Address::decode(&decode(&hash).map_err(ErrorInternalServerError)?)
+        let address = Address::decode(&b58_decode(&hash).map_err(ErrorInternalServerError)?)
             .map_err(ErrorInternalServerError)?;
         if let Address::Hash(address_hash) = address {
             let preview_result = preview_store
