@@ -1,5 +1,5 @@
 export type Address = string;
-export type VALUE_TYPE = "Value" | "Address" | "Invalid";
+export type VALUE_TYPE = "Address" | "String" | "Number" | "Invalid";
 
 export interface IEntry {
   entity: Address;
@@ -7,10 +7,30 @@ export interface IEntry {
   value: IValue;
 }
 
-export interface IValue {
-  t: VALUE_TYPE;
-  c: string | number;
-}
+const model: { [key in VALUE_TYPE as string]: unknown } = {
+  String: "string",
+  Address: "address",
+  Number: 123,
+  Invalid: null,
+};
+
+export type IValue =
+  | {
+      t: "Address";
+      c: string;
+    }
+  | {
+      t: "String";
+      c: string;
+    }
+  | {
+      t: "Number";
+      c: number;
+    }
+  | {
+      t: "Invalid";
+      c: null;
+    };
 
 export interface ListingResult {
   [key: string]: IEntry;
